@@ -1,6 +1,6 @@
 package DBD::Gofer::Transport::pipeone;
 
-#   $Id: pipeone.pm 9451 2007-04-25 15:57:06Z timbo $
+#   $Id: pipeone.pm 10087 2007-10-16 12:42:37Z timbo $
 #
 #   Copyright (c) 2007, Tim Bunce, Ireland
 #
@@ -18,7 +18,7 @@ use Symbol qw(gensym);
 
 use base qw(DBD::Gofer::Transport::Base);
 
-our $VERSION = sprintf("0.%06d", q$Revision: 9451 $ =~ /(\d+)/o);
+our $VERSION = sprintf("0.%06d", q$Revision: 10087 $ =~ /(\d+)/o);
 
 __PACKAGE__->mk_accessors(qw(
     connection_info
@@ -209,7 +209,7 @@ sub receive_response_by_transport {
 __END__
 
 =head1 NAME
-    
+
 DBD::Gofer::Transport::pipeone - DBD::Gofer client transport for testing
 
 =head1 SYNOPSIS
@@ -233,18 +233,21 @@ side is completely stateless.
 It also provides a base class for the much more useful L<DBD::Gofer::Transport::stream>
 transport.
 
-=head1 AUTHOR AND COPYRIGHT
+=head1 AUTHOR
 
-The DBD::Gofer, DBD::Gofer::* and DBI::Gofer::* modules are
-Copyright (c) 2007 Tim Bunce. Ireland.  All rights reserved.
+Tim Bunce, L<http://www.tim.bunce.name>
 
-You may distribute under the terms of either the GNU General Public License or
-the Artistic License, as specified in the Perl README file.
+=head1 LICENCE AND COPYRIGHT
 
+Copyright (c) 2007, Tim Bunce, Ireland. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
 
 =head1 SEE ALSO
 
+L<DBD::Gofer::Transport::Base>
+
 L<DBD::Gofer>
 
 =cut
-
