@@ -22,7 +22,8 @@ use warnings;
 require DBI; # for looks_like_number()
 use vars qw( $VERSION $versions );
 BEGIN {
-    $VERSION = '0.03';
+    $VERSION = sprintf("1.%06d", q$Revision: 9744 $ =~ /(\d+)/o);
+
     $versions->{nano_version} = $VERSION;
     if ($ENV{DBI_SQL_NANO} || !eval { require "SQL/Statement.pm" }) {
         @DBI::SQL::Nano::Statement::ISA = qw(DBI::SQL::Nano::Statement_);
@@ -132,7 +133,7 @@ sub parse_coldef_list  {                # check column definitions
     return \@col_defs;
 }
 sub parse_comma_list  {[map{clean_parse_str($_)} split(',',shift)]}
-sub clean_parse_str { $_ = shift; s/\(//;s/\)//;s/^\s+//; s/\s+$//; $_; }
+sub clean_parse_str { local $_ = shift; s/\(//;s/\)//;s/^\s+//; s/\s+$//; $_; }
 sub parse_values_list {
     my($self,$str) = @_;
     [map{$self->parse_value(clean_parse_str($_))}split(',',$str)]
